@@ -2,7 +2,7 @@ import json
 from typing import Dict
 from inspect import isclass
 
-__version__ = '0.6.5'
+__version__ = '0.6.6'
 
 renderers: Dict = {}
 
@@ -61,6 +61,18 @@ class Text(BaseNode):
         return text
 
 
+class Heading(Text):
+    type = "heading"
+
+    def inner_render(self, node) -> str:
+        attrs = node['attrs']
+        level = attrs.get('level') or 1
+        tag = f"h{level}"
+        cnodes = node.get('content')
+        inner_html = ''.join(Text.inner_render(self, cnode) for cnode in cnodes)
+        return f"<{tag}>{inner_html}</{tag}>"
+
+
 class Image(BaseNode):
     type = "image"
     wrap_tag: str = "figure"
@@ -93,16 +105,6 @@ class Embed(BaseContainer):
         return f'<div class="embed-wrapper {provider_name.lower()}-wrapper"><figure>{html}</figure></div>'  # noqa: E501
 
 
-class Heading(BaseContainer):
-    type = "heading"
-
-    def inner_render(self, node) -> str:
-        attrs = node['attrs']
-        level = attrs.get('level') or 3
-        content = node.get('content', '')
-        return f"<h{level}>{content}</h{level}>"
-
-
 class Title(BaseContainer):
     type = "title"
     wrap_tag: str = "h1"
